@@ -11,35 +11,34 @@
  *  This file is part of DrumGizmo.
  *
  *  DrumGizmo is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  DrumGizmo is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with DrumGizmo; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
  */
 
-#ifndef __DRUMGIZMOC_H__
-#define __DRUMGIZMOC_H__
+#pragma once
 
 #include "messagereceiver.h"
 
-class CliMain : public MessageReceiver {
+class CliMain : public MessageReceiver
+{
 public:
-  CliMain();
-  virtual ~CliMain();
+	CliMain();
+	virtual ~CliMain();
+
+	int run(int argc, char* argv[]);
+	void handleMessage(Message* msg);
 
-  int run(int argc, char *argv[]);
-  void handleMessage(Message *msg);
 private:
-  bool loading;
+	bool loading;
 };
 
-#endif//__DRUMGIZMOC_H__
-
