@@ -11,41 +11,38 @@
  *  This file is part of DrumGizmo.
  *
  *  DrumGizmo is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  DrumGizmo is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with DrumGizmo; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
  */
-#ifndef __DRUMGIZMO_COLOUR_H__
-#define __DRUMGIZMO_COLOUR_H__
+#pragma once
 
 namespace GUI {
 
 class Colour {
 public:
-  Colour();
+	Colour();
 
-  Colour(float grey, float alpha = 1.0);
+	Colour(float grey, float alpha = 1.0);
 
-  Colour(float red,
-         float green,
-         float blue,
-         float alpha = 1.0);
+	Colour(float red,
+	       float green,
+	       float blue,
+	       float alpha = 1.0);
 
-  float red;
-  float green;
-  float blue;
-  float alpha;
+	float red;
+	float green;
+	float blue;
+	float alpha;
 };
 
-};
-
-#endif/*__DRUMGIZMO_COLOUR_H__*/
+} // GUI::
