@@ -1,6 +1,6 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /***************************************************************************
- *            config.h
+ *            pluginconfig.h
  *
  *  Tue Jun  3 13:51:29 CEST 2014
  *  Copyright 2014 Jonas Suhr Christensen
@@ -11,38 +11,35 @@
  *  This file is part of DrumGizmo.
  *
  *  DrumGizmo is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  DrumGizmo is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with DrumGizmo; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
  */
-#ifndef __DRUMGIZMO_CONFIG_H__
-#define __DRUMGIZMO_CONFIG_H__
+#pragma once
 
-#include <string>
-#include <list>
+#include <configfile.h>
 
-#define DIRECTORY_HIDDEN 1
+namespace GUI {
 
-class Config {
+class Config : public ConfigFile {
+public:
+	Config();
+	~Config();
 
-  public:
-    Config();
-    ~Config();
+	bool load();
+	bool save();
 
-    void load();
-    void save();
-
-    std::string lastkit;
-    std::string lastmidimap;
+	std::string lastkit;
+	std::string lastmidimap;
 };
 
-#endif/*__DRUMGIZMO_CONFIG_H__*/
+} // GUI::
