@@ -8,20 +8,20 @@
  ****************************************************************************/
 
 /*
- *  This file is part of Pracro.
+ *  This file is part of DrumGizmo.
  *
- *  Pracro is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  DrumGizmo is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  Pracro is distributed in the hope that it will be useful,
+ *  DrumGizmo is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with Pracro; if not, write to the Free Software
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with DrumGizmo; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
  */
 #ifndef __PRACRO_SEMAPHORE_H__
@@ -38,8 +38,8 @@ public:
   void wait();
 
 private:
-  struct semaphore_private_t *prv;
-  const char *name;
+	struct semaphore_private_t *prv{nullptr};
+	const char *name{nullptr};
 };
 
 #endif/*__PRACRO_SEMAPHORE_H__*/
